diff --git a/dumux/porousmediumflow/1p/implicit/volumevariables.hh b/dumux/porousmediumflow/1p/implicit/volumevariables.hh
index d46fd315569562d895e140f56fbfcddc3eabe256..f7ccc4daf7d98edaa265423a62bf5296042b2489 100644
--- a/dumux/porousmediumflow/1p/implicit/volumevariables.hh
+++ b/dumux/porousmediumflow/1p/implicit/volumevariables.hh
@@ -25,7 +25,7 @@
 #define DUMUX_1P_VOLUME_VARIABLES_HH
 
 #include <dumux/common/properties.hh>
-#include <dumux/discretization/volumevariables.hh>
+#include <dumux/porousmediumflow/volumevariables.hh>
 #include <dumux/material/fluidstates/immiscible.hh>
 
 namespace Dumux
@@ -33,14 +33,13 @@ namespace Dumux
 
 /*!
  * \ingroup OnePModel
- * \ingroup ImplicitVolumeVariables
  * \brief Contains the quantities which are constant within a
  *        finite volume in the one-phase model.
  */
 template <class TypeTag>
-class OnePVolumeVariables : public ImplicitVolumeVariables<TypeTag>
+class OnePVolumeVariables : public PorousMediumFlowVolumeVariables<TypeTag>
 {
-    using ParentType = ImplicitVolumeVariables<TypeTag>;
+    using ParentType = PorousMediumFlowVolumeVariables<TypeTag>;
     using Implementation = typename GET_PROP_TYPE(TypeTag, VolumeVariables);
     using Scalar = typename GET_PROP_TYPE(TypeTag, Scalar);
     using Problem = typename GET_PROP_TYPE(TypeTag, Problem);
diff --git a/dumux/porousmediumflow/1pnc/implicit/volumevariables.hh b/dumux/porousmediumflow/1pnc/implicit/volumevariables.hh
index 775dbaf0a88db1cd070c1a1e18d9b34f0ff8eb42..d005c0bfc4444c4a42fd19f75c28c92e0da1211c 100644
--- a/dumux/porousmediumflow/1pnc/implicit/volumevariables.hh
+++ b/dumux/porousmediumflow/1pnc/implicit/volumevariables.hh
@@ -26,14 +26,13 @@
 #define DUMUX_1PNC_VOLUME_VARIABLES_HH
 
 #include <dumux/common/properties.hh>
-#include <dumux/discretization/volumevariables.hh>
+#include <dumux/porousmediumflow/volumevariables.hh>
 
 namespace Dumux
 {
 
 /*!
  * \ingroup OnePNCModel
- * \ingroup ImplicitVolumeVariables
  * \brief Contains the quantities which are are constant within a
  *        finite volume in the one-phase, n-component model.
  *
@@ -45,9 +44,9 @@ namespace Dumux
  *       model by specifying which phase is present through the DuMuX property system.
  */
 template <class TypeTag>
-class OnePNCVolumeVariables : public ImplicitVolumeVariables<TypeTag>
+class OnePNCVolumeVariables : public PorousMediumFlowVolumeVariables<TypeTag>
 {
-    using ParentType = ImplicitVolumeVariables<TypeTag>;
+    using ParentType = PorousMediumFlowVolumeVariables<TypeTag>;
 
     using Scalar = typename GET_PROP_TYPE(TypeTag, Scalar);
     using Problem = typename GET_PROP_TYPE(TypeTag, Problem);
diff --git a/dumux/porousmediumflow/2p/implicit/volumevariables.hh b/dumux/porousmediumflow/2p/implicit/volumevariables.hh
index 0ca216a6583c6eccc420b95ef1ab5a33f05e2f63..56954663f60862035960d2055203060902bf33f3 100644
--- a/dumux/porousmediumflow/2p/implicit/volumevariables.hh
+++ b/dumux/porousmediumflow/2p/implicit/volumevariables.hh
@@ -26,21 +26,20 @@
 #define DUMUX_2P_VOLUME_VARIABLES_HH
 
 #include <dumux/common/properties.hh>
-#include <dumux/discretization/volumevariables.hh>
+#include <dumux/porousmediumflow/volumevariables.hh>
 #include <dune/common/fvector.hh>
 
 namespace Dumux
 {
 /*!
  * \ingroup TwoPModel
- * \ingroup ImplicitVolumeVariables
  * \brief Contains the quantities which are are constant within a
  *        finite volume in the two-phase model.
  */
 template <class TypeTag>
-class TwoPVolumeVariables : public ImplicitVolumeVariables<TypeTag>
+class TwoPVolumeVariables : public PorousMediumFlowVolumeVariables<TypeTag>
 {
-    using ParentType = ImplicitVolumeVariables<TypeTag>;
+    using ParentType = PorousMediumFlowVolumeVariables<TypeTag>;
 
     using Implementation = typename GET_PROP_TYPE(TypeTag, VolumeVariables);
     using Scalar = typename GET_PROP_TYPE(TypeTag, Scalar);
diff --git a/dumux/porousmediumflow/2p1c/volumevariables.hh b/dumux/porousmediumflow/2p1c/volumevariables.hh
index 24b9949ac61bd91b162c747fef0da723b7b96160..793663c86d3fa2ce62cef818d18fda8e9606076b 100644
--- a/dumux/porousmediumflow/2p1c/volumevariables.hh
+++ b/dumux/porousmediumflow/2p1c/volumevariables.hh
@@ -36,7 +36,6 @@ namespace Dumux
 
 /*!
  * \ingroup TwoPOneCModel
- * \ingroup PorousmediumflowVolumeVariables
  * \brief Contains the quantities which are are constant within a
  *        finite volume in the two-phase, two-component model.
  */
diff --git a/dumux/porousmediumflow/2pnc/volumevariables.hh b/dumux/porousmediumflow/2pnc/volumevariables.hh
index 571be88c0b4f3a8223ad3658c25053838e6aa797..c573c021ac707564302f9714781b095f68c3c2a8 100644
--- a/dumux/porousmediumflow/2pnc/volumevariables.hh
+++ b/dumux/porousmediumflow/2pnc/volumevariables.hh
@@ -32,7 +32,7 @@
 #include <dumux/common/properties.hh>
 
 #include <dumux/material/fluidstates/compositional.hh>
-#include <dumux/discretization/volumevariables.hh>
+#include <dumux/porousmediumflow/volumevariables.hh>
 #include <dumux/material/constraintsolvers/computefromreferencephase.hh>
 #include <dumux/material/constraintsolvers/miscible2pnccomposition.hh>
 
@@ -43,14 +43,13 @@ namespace Dumux
 
 /*!
  * \ingroup TwoPNCModel
- * \ingroup ImplicitVolumeVariables
  * \brief Contains the quantities which are are constant within a
  *        finite volume in the two-phase, n-component model.
  */
 template <class TypeTag>
-class TwoPNCVolumeVariables : public ImplicitVolumeVariables<TypeTag>
+class TwoPNCVolumeVariables : public PorousMediumFlowVolumeVariables<TypeTag>
 {
-    using ParentType = ImplicitVolumeVariables<TypeTag>;
+    using ParentType = PorousMediumFlowVolumeVariables<TypeTag>;
     using Implementation = typename GET_PROP_TYPE(TypeTag, VolumeVariables);
     using Scalar = typename GET_PROP_TYPE(TypeTag, Scalar);
     using Grid = typename GET_PROP_TYPE(TypeTag, Grid);
diff --git a/dumux/porousmediumflow/3p/volumevariables.hh b/dumux/porousmediumflow/3p/volumevariables.hh
index 6d33c70fcc1e0123da0d6ce1471070ec4df8708a..0c04f5964ed217bb6a309a32f6b55d7134c46378 100644
--- a/dumux/porousmediumflow/3p/volumevariables.hh
+++ b/dumux/porousmediumflow/3p/volumevariables.hh
@@ -28,7 +28,7 @@
 #include <dumux/common/properties.hh>
 #include <dumux/material/constants.hh>
 #include <dumux/material/fluidstates/immiscible.hh>
-#include <dumux/discretization/volumevariables.hh>
+#include <dumux/porousmediumflow/volumevariables.hh>
 #include <dumux/discretization/methods.hh>
 
 namespace Dumux
@@ -36,14 +36,13 @@ namespace Dumux
 
 /*!
  * \ingroup ThreePModel
- * \ingroup ImplicitVolumeVariables
  * \brief Contains the quantities which are are constant within a
  *        finite volume in three-phase model.
  */
 template <class TypeTag>
-class ThreePVolumeVariables : public ImplicitVolumeVariables<TypeTag>
+class ThreePVolumeVariables : public PorousMediumFlowVolumeVariables<TypeTag>
 {
-    using ParentType = ImplicitVolumeVariables<TypeTag>;
+    using ParentType = PorousMediumFlowVolumeVariables<TypeTag>;
 
     using Implementation = typename GET_PROP_TYPE(TypeTag, VolumeVariables);
     using Scalar = typename GET_PROP_TYPE(TypeTag, Scalar);
diff --git a/dumux/porousmediumflow/3p3c/implicit/volumevariables.hh b/dumux/porousmediumflow/3p3c/implicit/volumevariables.hh
index 8850570fce4a86caa2fede675a4b93567f1278c3..3d327521a61add19480576e211003e4ba7b2c9a9 100644
--- a/dumux/porousmediumflow/3p3c/implicit/volumevariables.hh
+++ b/dumux/porousmediumflow/3p3c/implicit/volumevariables.hh
@@ -30,7 +30,7 @@
 #include <dumux/material/fluidstates/compositional.hh>
 #include <dumux/material/constraintsolvers/computefromreferencephase.hh>
 #include <dumux/material/constraintsolvers/misciblemultiphasecomposition.hh>
-#include <dumux/discretization/volumevariables.hh>
+#include <dumux/porousmediumflow/volumevariables.hh>
 #include <dumux/discretization/methods.hh>
 
 namespace Dumux
@@ -38,14 +38,13 @@ namespace Dumux
 
 /*!
  * \ingroup ThreePThreeCModel
- * \ingroup ImplicitVolumeVariables
  * \brief Contains the quantities which are are constant within a
  *        finite volume in the three-phase three-component model.
  */
 template <class TypeTag>
-class ThreePThreeCVolumeVariables : public ImplicitVolumeVariables<TypeTag>
+class ThreePThreeCVolumeVariables : public PorousMediumFlowVolumeVariables<TypeTag>
 {
-    using ParentType = ImplicitVolumeVariables<TypeTag>;
+    using ParentType = PorousMediumFlowVolumeVariables<TypeTag>;
 
     using Implementation = typename GET_PROP_TYPE(TypeTag, VolumeVariables);
     using Scalar = typename GET_PROP_TYPE(TypeTag, Scalar);
diff --git a/dumux/porousmediumflow/richards/implicit/volumevariables.hh b/dumux/porousmediumflow/richards/implicit/volumevariables.hh
index ce955b0ac2e9a7d5442490d5787e7d2308f31586..4e23e719b7125d641ce400cee64f6d8606593c01 100644
--- a/dumux/porousmediumflow/richards/implicit/volumevariables.hh
+++ b/dumux/porousmediumflow/richards/implicit/volumevariables.hh
@@ -25,7 +25,7 @@
 #define DUMUX_RICHARDS_VOLUME_VARIABLES_HH
 
 #include <dumux/common/properties.hh>
-#include <dumux/discretization/volumevariables.hh>
+#include <dumux/porousmediumflow/volumevariables.hh>
 #include <dumux/material/idealgas.hh>
 #include <dumux/material/constants.hh>
 
@@ -34,16 +34,15 @@ namespace Dumux
 
 /*!
  * \ingroup RichardsModel
- * \ingroup ImplicitVolumeVariables
  * \brief Volume averaged quantities required by the Richards model.
  *
  * This contains the quantities which are are constant within a finite
  * volume in the Richards model
  */
 template <class TypeTag>
-class RichardsVolumeVariables : public ImplicitVolumeVariables<TypeTag>
+class RichardsVolumeVariables : public PorousMediumFlowVolumeVariables<TypeTag>
 {
-    using ParentType = ImplicitVolumeVariables<TypeTag>;
+    using ParentType = PorousMediumFlowVolumeVariables<TypeTag>;
     using Implementation = typename GET_PROP_TYPE(TypeTag, VolumeVariables);
     using Scalar = typename GET_PROP_TYPE(TypeTag, Scalar);
     using Problem = typename GET_PROP_TYPE(TypeTag, Problem);
diff --git a/dumux/porousmediumflow/richardsnc/implicit/volumevariables.hh b/dumux/porousmediumflow/richardsnc/implicit/volumevariables.hh
index b9d2890b409c4b25b3e15052c6edc5450d1e8f50..6553b29e3fa7e0ac7f7e426e3254942914c79714 100644
--- a/dumux/porousmediumflow/richardsnc/implicit/volumevariables.hh
+++ b/dumux/porousmediumflow/richardsnc/implicit/volumevariables.hh
@@ -24,15 +24,15 @@
 #define DUMUX_RICHARDSNC_VOLUME_VARIABLES_HH
 
 #include <dumux/common/properties.hh>
-#include <dumux/discretization/volumevariables.hh>
+#include <dumux/porousmediumflow/volumevariables.hh>
 
 namespace Dumux
 {
 
 template <class TypeTag>
-class RichardsBaseVolumeVariables : public ImplicitVolumeVariables<TypeTag>
+class RichardsBaseVolumeVariables : public PorousMediumFlowVolumeVariables<TypeTag>
 {
-    using ParentType = ImplicitVolumeVariables<TypeTag>;
+    using ParentType = PorousMediumFlowVolumeVariables<TypeTag>;
     using Implementation = typename GET_PROP_TYPE(TypeTag, VolumeVariables);
     using Scalar = typename GET_PROP_TYPE(TypeTag, Scalar);
     using Problem = typename GET_PROP_TYPE(TypeTag, Problem);
diff --git a/dumux/porousmediumflow/tracer/volumevariables.hh b/dumux/porousmediumflow/tracer/volumevariables.hh
index e4f1e946aa2f4d1d1810e3911026d0f788de21c9..b1771fdd5ce844af8b379d42357246265eabffb3 100644
--- a/dumux/porousmediumflow/tracer/volumevariables.hh
+++ b/dumux/porousmediumflow/tracer/volumevariables.hh
@@ -24,21 +24,20 @@
 #define DUMUX_TRACER_VOLUME_VARIABLES_HH
 
 #include <dumux/common/properties.hh>
-#include <dumux/discretization/volumevariables.hh>
+#include <dumux/porousmediumflow/volumevariables.hh>
 
 namespace Dumux
 {
 
 /*!
  * \ingroup TracerModel
- * \ingroup ImplicitVolumeVariables
  * \brief Contains the quantities which are constant within a
  *        finite volume for the tracer model.
  */
 template <class TypeTag>
-class TracerVolumeVariables : public ImplicitVolumeVariables<TypeTag>
+class TracerVolumeVariables : public PorousMediumFlowVolumeVariables<TypeTag>
 {
-    using ParentType = ImplicitVolumeVariables<TypeTag>;
+    using ParentType = PorousMediumFlowVolumeVariables<TypeTag>;
 
     using Scalar = typename GET_PROP_TYPE(TypeTag, Scalar);
     using Problem = typename GET_PROP_TYPE(TypeTag, Problem);
diff --git a/dumux/discretization/volumevariables.hh b/dumux/discretization/volumevariables.hh
index ab8a37974eeeaddba859fddf5d32a3c9ed57cd3c..304740e6f483dd9f629a141db9cab1ae4e5d68aa 100644
--- a/dumux/discretization/volumevariables.hh
+++ b/dumux/discretization/volumevariables.hh
@@ -24,7 +24,7 @@
 #ifndef DUMUX_DISCRETIZATION_VOLUME_VARIABLES_DEPR_HH
 #define DUMUX_DISCRETIZATION_VOLUME_VARIABLES_DEPR_HH
 
 #warning "This header is deprecated. Use PorousmediumflowVolumeVariables from dumux/porousmediumflow/volumevariables.hh"
 #include <dune/common/deprecated.hh>
 #include <dumux/porousmediumflow/volumevariables.hh>
 
@@ -32,7 +32,7 @@ namespace Dumux
 {
 
 template<class TypeTag>
-using ImplicitVolumeVariables DUNE_DEPRECATED_MSG("Use PorousmediumflowVolumeVariables from dumux/porousmediumflow/volumevariables.hh")
+using ImplicitVolumeVariables DUNE_DEPRECATED_MSG("Use PorousMediumFlowVolumeVariables from dumux/porousmediumflow/volumevariables.hh")
 = PorousMediumFlowVolumeVariables<TypeTag>;
 
 } // end namespace Dumux
@@ -24,7 +24,7 @@
 #define DUMUX_DISCRETIZATION_VOLUME_VARIABLES_DEPR_HH
 
-#warning "This header is deprecated. Use PorousmediumflowVolumeVariables from dumux/porousmediumflow/volumevariables.hh"
+#warning "This header is deprecated. Use PorousMediumFlowVolumeVariables from dumux/porousmediumflow/volumevariables.hh"
 #include <dune/common/deprecated.hh>
 #include <dumux/porousmediumflow/volumevariables.hh>